@@ -6,13 +6,14 @@ __all__ = [
     'directory_size',
     'is_file_in_directory',
     'get_ocrd_tool_json',
+    'get_moduledir',
     'get_processor_resource_types',
     'pushd_popd',
     'unzip_file_to_dir',
     'atomic_write',
 ]
 
-from tempfile import TemporaryDirectory
+from tempfile import TemporaryDirectory, gettempdir
 from functools import lru_cache
 import contextlib
 from distutils.spawn import find_executable as which
@@ -47,16 +48,16 @@ def pushd_popd(newcwd=None, tempdir=False):
         oldcwd = getcwd()
     except FileNotFoundError:
         # This happens when a directory is deleted before the context is exited
-        oldcwd = '/tmp'
+        oldcwd = gettempdir()
     try:
         if tempdir:
             with TemporaryDirectory() as tempcwd:
                 chdir(tempcwd)
-                yield tempcwd
+                yield Path(tempcwd).resolve()
         else:
             if newcwd:
                 chdir(newcwd)
-            yield newcwd
+            yield Path(newcwd).resolve()
     finally:
         chdir(oldcwd)
 
@@ -83,11 +84,14 @@ def get_ocrd_tool_json(executable):
         ocrd_tool['resource_locations'] = ['data', 'cwd', 'system', 'module']
     return ocrd_tool
 
-# def get_processor_resources_list(executable):
-#     """
-#     Get the list of resources that a processor is providing via
-#     ``-list-resources``
-#     """
+@lru_cache()
+def get_moduledir(executable):
+    moduledir = None
+    try:
+        moduledir = run([executable, '--dump-module-dir'], encoding='utf-8', stdout=PIPE).stdout.rstrip('\n')
+    except (JSONDecodeError, OSError) as e:
+        getLogger('ocrd_utils.get_moduledir').error(f'{executable} --dump-module-dir failed: {e}')
+    return moduledir
 
 def list_resource_candidates(executable, fname, cwd=getcwd(), moduled=None, xdg_data_home=None):
     """
